@@ -1,5 +1,5 @@
 from django.contrib import admin
-from radioweb.radio.models import *
+from liquidjango.models import *
 
 class SongAdmin(admin.ModelAdmin):
     list_display = ('title', 'artist', 'length', 'filehash')
