@@ -1,6 +1,6 @@
 from django.conf.urls.defaults import *
 from django.contrib import admin
-from radioweb.radio.models import *
+from liquidjango.models import *
 from django.contrib.auth.views import login , password_reset , logout_then_login
 
 # Uncomment the next two lines to enable the admin:
